import os
import numpy as np
import math
import iris
import iris.cube
import iris.analysis
import iris.util
from iris.coords import DimCoord
import warnings
import numba
import datetime
from numba import jit, njit
from numba import vectorize
from numba import guvectorize
from numba import cuda
from numba import int32, int64, float32, float64
from numba.cuda.cudadrv import driver

VSFTMYZ_FILE = '/esarchive/exp/ecearth/a16l/cmorfiles/CMIP'\
               '/EC-Earth-Consortium/EC-Earth3-LR/historical/r1i1p1f1/Omon'\
               '/vsftmyz/gn/v20180711/vsftmyz_Omon_EC-Earth3-LR_historical_'\
               'r1i1p1f1_gn_196101-196112.nc'


def main():
    one_layer = ((0, 300),)
    min_lat = 40
    max_lat = 50
    min_depth = 1000
    max_depth = 2000
    vsftmyz = load_vsftmyz(min_lat, max_lat, min_depth, max_depth)
    vsftmyz = np.squeeze(vsftmyz)
    levels = vsftmyz.shape[1]
    lats = vsftmyz.shape[2]
    basins = vsftmyz.shape[3]


def load_vsftmyz(min_lat, max_lat, min_depth, max_depth):
    long_name = 'Ocean meridional overturning volume streamfunction'
    vsftmyz = iris.load_cube(VSFTMYZ_FILE, long_name)
    vsftmyz = add_coord_names(vsftmyz)
    vsftmyz = latitude_constraint(min_lat, max_lat, vsftmyz)
    vsftmyz = depth_constraint(min_depth, max_depth, vsftmyz)
    vsftmyz_data = np.ma.filled(vsftmyz.data, 0.0).astype(np.float32)
    return vsftmyz_data


def add_coord_names(cube):
    dims = len(cube.shape)
    cube.add_dim_coord(
        DimCoord(np.arange(cube.shape[dims - 1]), var_name='basin'),
        dims - 1
    )
    cube.add_dim_coord(
        DimCoord(np.arange(cube.shape[dims - 2]), var_name='latitude'),
        dims - 2
    )
    cube.add_dim_coord(
        DimCoord(np.arange(cube.shape[dims - 3]), var_name='longitude'),
        dims - 3
    )
    return cube


def latitude_constraint(min_lat, max_lat, cube):
    constraint = iris.Constraint(latitude=lambda c: min_lat <= c <= max_lat)
    cube = cube.extract(constraint)
    return cube


def depth_constraint(min_depth, max_depth, cube):
    constraint = iris.Constraint(depth=lambda c: min_depth <= c <= max_depth)
    cube = cube.extract(constraint)
    return cube


if __name__ == '__main__':
    main()
