import sys
from setuptools import Command, setup


PACKAGES = [
    'diagonals',
]

REQUIREMENTS = {
    # Installation script (this file) dependencies
    # Installation dependencies
    # Use with pip install . to install from source
    'install': [
        'netCDF4',
        'numba',
        'numpy',
        'six',
    ],
    'gpu': [
        'pycuda'
    ],
    'test':[
        'mock',
        'pycodestyle',
        'pytest',
        'pytest-cov',
        'pytest-html',
    ]

}

class RunTests(Command):
    """Class to run tests and generate reports."""

    user_options = []

    def initialize_options(self):
        """Do nothing."""

    def finalize_options(self):
        """Do nothing."""

    def run(self):
        """Run tests and generate a coverage report."""
        import pytest

        version = sys.version_info[0]
        report_dir = 'test/report/python{}'.format(version)
        args = [
            'test',
            'diagonals',  # for doctests
            '--ignore=test/report',
            '--doctest-modules',
            '--cov=diagonals',
            '--cov-report=term',
            '--cov-report=html:{}/coverage_html'.format(report_dir),
            '--cov-report=xml:{}/coverage.xml'.format(report_dir),
            '--junit-xml={}/report.xml'.format(report_dir),
            '--html={}/report.html'.format(report_dir),
        ]
        errno = pytest.main(args)
        sys.exit(errno)


setup(name='diagonals',
      version='0.1',
      description='Compute diagnostics targeting the CPU or the GPU',
      url='https://earth.bsc.es/gitlab/es/diagonals',
      author='BSC-CNS Earth Sciences Department',
      author_email='saskia.loosveldt@bsc.es',
      classifiers=[
          'Environment :: Console',
          'License :: OSI Approved :: Apache Software License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.6',
      ],
      packages=PACKAGES,
      install_requires=REQUIREMENTS['install'],
      extras_require={
          'gpu': REQUIREMENTS['gpu'],
          'test': REQUIREMENTS['test'],
      },
      cmdclass={
            'test': RunTests,
      },
      zip_safe=False,)
